// ------------------------------------
// Filename      : SimpleTunePlayer.cpp
// Author        : Sven Maerivoet
// Last modified : 15/11/2015
// Target        : C++ (Arduino UNO)
//
// All rights reserved.
// ------------------------------------

/*
 Copyright 2015 Sven Maerivoet
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
   http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
*/

#include "Arduino.h"
#include "SimpleTunePlayer.h"

// ***********
// CONSTRUCTOR
// ***********

SimpleTunePlayer::SimpleTunePlayer(int speakerPin)
{
  fSpeakerPin = speakerPin;
  pinMode(fSpeakerPin,OUTPUT);
}

// **************
// PUBLIC METHODS
// **************

void SimpleTunePlayer::playNote(Notes::ENotes note, int durationMs)
{
	playNote(note,durationMs,0);
}

void SimpleTunePlayer::playNote(Notes::ENotes note, int durationMs, int deltaOctave)
{
  if (note != Notes::kPAUSE) {
    tone(fSpeakerPin,getFrequency(note) * pow(2,deltaOctave));
  }
  delay(durationMs);
  noTone(fSpeakerPin);
}

void SimpleTunePlayer::playTune(Notes::ENotes notes[], int durations[], int nrOfNotes)
{
  for (int i = 0; i < nrOfNotes; ++i) {
    playNote(notes[i],durations[i]);
  }
}

void SimpleTunePlayer::playTune(Notes::ENotes notes[], int durations[], int nrOfNotes, int deltaOctave)
{
  for (int i = 0; i < nrOfNotes; ++i) {
    playNote(notes[i],durations[i],deltaOctave);
  }
}

// ***************
// PRIVATE METHODS
// ***************

int SimpleTunePlayer::getFrequency(Notes::ENotes note)
{
  int frequency = 0;
  switch (note) {
    case Notes::kC:
      frequency = 261;
      break;
    case Notes::kD:
      frequency = 294;
      break;
    case Notes::kE:
      frequency = 329;
      break;
    case Notes::kF:
      frequency = 349;
      break;
    case Notes::kG:
      frequency = 392;
      break;
    case Notes::kA:
      frequency = 440;
      break;
    case Notes::kB:
      frequency = 493;
      break;
    default: break;
  }

  return frequency;
}
