// ----------------------------------
// Filename      : SimpleTunePlayer.h
// Author        : Sven Maerivoet
// Last modified : 15/11/2015
// Target        : C++ (Arduino UNO)
//
// All rights reserved.
// ----------------------------------

/*
 Copyright 2015 Sven Maerivoet
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 
   http://www.apache.org/licenses/LICENSE-2.0
 
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
*/

#ifndef SIMPLETUNEPLAYER_h
#define SIMPLETUNEPLAYER_h

#include "Arduino.h"

class Notes {
  public:
    enum ENotes {kC, kD, kE, kF, kG, kA, kB, kPAUSE};
	  static const int kFull = 666 / 2;
	  static const int kHalf = kFull / 2;
	  static const int kQuarter = kHalf / 2;
	  static const int kEight = kQuarter / 4;
	  static const int kDouble = kFull * 2;
	  static const int kQuadruple = kDouble * 2;
};

class SimpleTunePlayer
{
  public:
    // constructor
    SimpleTunePlayer(int speakerPin);

    // public methods
    void playNote(Notes::ENotes note, int duration);
    void playNote(Notes::ENotes note, int duration, int deltaOctave);
    void playTune(Notes::ENotes notes[], int durations[], int nrOfNotes);
    void playTune(Notes::ENotes notes[], int durations[], int nrOfNotes, int deltaOctave);

  private:
    // pin assignments
    int fSpeakerPin;

    // private methods
    int getFrequency(Notes::ENotes note);
};

#endif
